@@ -8,7 +8,8 @@ import subprocess
 from os.path import expanduser
 import six
 from boto3 import Session
-from localstack.constants import DEFAULT_SERVICE_PORTS, LOCALHOST, PATH_USER_REQUEST, DEFAULT_PORT_WEB_UI
+from localstack.constants import (
+    DEFAULT_SERVICE_PORTS, LOCALHOST, PATH_USER_REQUEST, DEFAULT_PORT_WEB_UI, TRUE_STRINGS, FALSE_STRINGS)
 
 TRUE_VALUES = ('1', 'true')
 
@@ -60,7 +61,7 @@ HOST_TMP_FOLDER = os.environ.get('HOST_TMP_FOLDER', TMP_FOLDER)
 DATA_DIR = os.environ.get('DATA_DIR', '').strip()
 
 # whether to use SSL encryption for the services
-USE_SSL = os.environ.get('USE_SSL', '').strip() not in ('0', 'false', '')
+USE_SSL = os.environ.get('USE_SSL', '').strip() in TRUE_STRINGS
 
 # default encoding used to convert strings to byte arrays (mainly for Python 3 compatibility)
 DEFAULT_ENCODING = 'utf-8'
@@ -74,6 +75,9 @@ DOCKER_FLAGS = os.environ.get('DOCKER_FLAGS', '').strip()
 # command used to run Docker containers (e.g., set to "sudo docker" to run as sudo)
 DOCKER_CMD = os.environ.get('DOCKER_CMD', '').strip() or 'docker'
 
+# whether to start the web API
+START_WEB = os.environ.get('START_WEB', '').strip() not in FALSE_STRINGS
+
 # port of Web UI
 PORT_WEB_UI = int(os.environ.get('PORT_WEB_UI', '').strip() or DEFAULT_PORT_WEB_UI)
 PORT_WEB_UI_SSL = PORT_WEB_UI + 1
