@@ -2,7 +2,7 @@ import os
 import localstack_client.config
 
 # LocalStack version
-VERSION = '0.10.3.1'
+VERSION = '0.10.3.2'
 
 # constant to represent the "local" region, i.e., local machine
 REGION_LOCAL = 'local'
@@ -68,6 +68,10 @@ APPLICATION_AMZ_JSON_1_1 = 'application/x-amz-json-1.1'
 APPLICATION_JSON = 'application/json'
 APPLICATION_X_WWW_FORM_URLENCODED = 'application/x-www-form-urlencoded'
 
+# strings to indicate truthy/falsy values
+TRUE_STRINGS = ('1', 'true', 'True')
+FALSE_STRINGS = ('0', 'false', 'False')
+
 # Lambda defaults
 LAMBDA_TEST_ROLE = 'arn:aws:iam::%s:role/lambda-test-role' % TEST_AWS_ACCOUNT_ID
 
